@@ -96,7 +96,7 @@ void personal_photo_frame_read_settings ( PersonalPhotoFrame *self )
 		}
         self->priv->singleFilename = g_key_file_get_string (keyFile, "config", "singleFilename", &error);
         if (error) {
-            self->priv->singleFilename = "";
+            self->priv->singleFilename = "/usr/share/icons/hicolor/scalable/hildon/personal-photo-frame.png";
             g_error_free (error);
             error = NULL;
         }
@@ -120,7 +120,7 @@ void personal_photo_frame_read_settings ( PersonalPhotoFrame *self )
 		}
     } else {
 		self->priv->singleMode = TRUE;
-        self->priv->singleFilename = "";
+        self->priv->singleFilename = "/usr/share/icons/hicolor/scalable/hildon/personal-photo-frame.png";
 		self->priv->slideshowDirname = "";
 		self->priv->slideshowDuration = 0;
 		self->priv->slideshowRandom = FALSE;
